@@ -95,6 +95,10 @@ export class MyStack extends cdk.Stack {
       //   }
       // },
       // debug: true, // Enable debug logging, show request + response, search for lines starting with "[tailscale-"
+      // warmer: { // Optional, enables a "warmer" Lambda to keep proxy connections open/warm (cold start is about 5-10 seconds)
+      //   functionName: name("tailscale-proxy-warmer"),
+      //   concurrentInvocations: 2,
+      // }
     });
 
     const caller = new NodejsFunction(this, "tailscale-caller", {
@@ -197,6 +201,16 @@ A Proxy Lambda error can be identified by the following headers in the response:
 * `ts-error-name`: The error name.
 * `ts-error-message`: The error message.
 
+### Reducing Cold starts
+
+Cold starts occur when your function first has to connect to the Tailscale network, which can take between 5-10 seconds
+as mentioned in the [Tailscale Lambda Extension](https://github.com/rehanvdm/tailscale-lambda-extension?tab=readme-ov-file#limitations)
+docs. Subsequent requests are much faster as the connection is reused.
+
+Cold starts can be mitigated by configuring a "warmer" Lambda function that periodically invokes the Proxy Lambda. The
+number of warm connections is determined by the `concurrentInvocations` property. This setup helps maintain a pool of
+warm connections to the Tailscale network, reducing latency for subsequent requests.
+
 ### Code Examples
 
 Refer to the [tailscale-lambda-proxy-example](https://github.com/rehanvdm/tailscale-lambda-proxy-example) repository
@@ -276,6 +290,7 @@ def check_type(argname: str, value: object, expected_type: typing.Any) -> typing
 
 from ._jsii import *
 
+import aws_cdk.aws_events as _aws_cdk_aws_events_ceddda9d
 import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
 import aws_cdk.aws_lambda_nodejs as _aws_cdk_aws_lambda_nodejs_ceddda9d
 import aws_cdk.aws_secretsmanager as _aws_cdk_aws_secretsmanager_ceddda9d
@@ -336,6 +351,18 @@ class TailscaleLambdaProxy(
     def lambda_function_url(self) -> _aws_cdk_aws_lambda_ceddda9d.FunctionUrl:
         return typing.cast(_aws_cdk_aws_lambda_ceddda9d.FunctionUrl, jsii.get(self, "lambdaFunctionUrl"))
 
+    @builtins.property
+    @jsii.member(jsii_name="warmer")
+    def warmer(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_lambda_nodejs_ceddda9d.NodejsFunction]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_nodejs_ceddda9d.NodejsFunction], jsii.get(self, "warmer"))
+
+    @builtins.property
+    @jsii.member(jsii_name="warmerRule")
+    def warmer_rule(self) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.Rule]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.Rule], jsii.get(self, "warmerRule"))
+
 
 @jsii.data_type(
     jsii_type="tailscale-lambda-proxy.TailscaleLambdaProxyProps",
@@ -469,7 +496,7 @@ class TailscaleLambdaProxyPropsLambdaOption:
 @jsii.data_type(
     jsii_type="tailscale-lambda-proxy.TailscaleLambdaProxyPropsOptions",
     jsii_struct_bases=[],
-    name_mapping={"extension": "extension", "lambda_": "lambda"},
+    name_mapping={"extension": "extension", "lambda_": "lambda", "warmer": "warmer"},
 )
 class TailscaleLambdaProxyPropsOptions:
     def __init__(
@@ -477,24 +504,31 @@ class TailscaleLambdaProxyPropsOptions:
         *,
         extension: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.LayerVersionOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         lambda_: typing.Optional[typing.Union[TailscaleLambdaProxyPropsLambdaOption, typing.Dict[builtins.str, typing.Any]]] = None,
+        warmer: typing.Optional[typing.Union["TailscaleLambdaProxyPropsWarmerOption", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param extension: 
         :param lambda_: 
+        :param warmer: If provided, a separate Lambda function will be created to periodically invoke the Tailscale proxy Lambda function to keep it warm.
         '''
         if isinstance(extension, dict):
             extension = _aws_cdk_aws_lambda_ceddda9d.LayerVersionOptions(**extension)
         if isinstance(lambda_, dict):
             lambda_ = TailscaleLambdaProxyPropsLambdaOption(**lambda_)
+        if isinstance(warmer, dict):
+            warmer = TailscaleLambdaProxyPropsWarmerOption(**warmer)
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__f012a3e49f709451167b5aea4e5d5e6bec3630984d9d528d842997a018da94e7)
             check_type(argname="argument extension", value=extension, expected_type=type_hints["extension"])
             check_type(argname="argument lambda_", value=lambda_, expected_type=type_hints["lambda_"])
+            check_type(argname="argument warmer", value=warmer, expected_type=type_hints["warmer"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if extension is not None:
             self._values["extension"] = extension
         if lambda_ is not None:
             self._values["lambda_"] = lambda_
+        if warmer is not None:
+            self._values["warmer"] = warmer
 
     @builtins.property
     def extension(
@@ -508,6 +542,12 @@ class TailscaleLambdaProxyPropsOptions:
         result = self._values.get("lambda_")
         return typing.cast(typing.Optional[TailscaleLambdaProxyPropsLambdaOption], result)
 
+    @builtins.property
+    def warmer(self) -> typing.Optional["TailscaleLambdaProxyPropsWarmerOption"]:
+        '''If provided, a separate Lambda function will be created to periodically invoke the Tailscale proxy Lambda function to keep it warm.'''
+        result = self._values.get("warmer")
+        return typing.cast(typing.Optional["TailscaleLambdaProxyPropsWarmerOption"], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -520,11 +560,63 @@ class TailscaleLambdaProxyPropsOptions:
         )
 
 
+@jsii.data_type(
+    jsii_type="tailscale-lambda-proxy.TailscaleLambdaProxyPropsWarmerOption",
+    jsii_struct_bases=[],
+    name_mapping={
+        "concurrent_invocations": "concurrentInvocations",
+        "function_name": "functionName",
+    },
+)
+class TailscaleLambdaProxyPropsWarmerOption:
+    def __init__(
+        self,
+        *,
+        concurrent_invocations: typing.Optional[jsii.Number] = None,
+        function_name: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param concurrent_invocations: 
+        :param function_name: 
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__ec060fb3c39fc12126fba615bdb9dfd4088bd14077c92dcc412180dec0a54ac3)
+            check_type(argname="argument concurrent_invocations", value=concurrent_invocations, expected_type=type_hints["concurrent_invocations"])
+            check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
+        if concurrent_invocations is not None:
+            self._values["concurrent_invocations"] = concurrent_invocations
+        if function_name is not None:
+            self._values["function_name"] = function_name
+
+    @builtins.property
+    def concurrent_invocations(self) -> typing.Optional[jsii.Number]:
+        result = self._values.get("concurrent_invocations")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def function_name(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("function_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "TailscaleLambdaProxyPropsWarmerOption(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 __all__ = [
     "TailscaleLambdaProxy",
     "TailscaleLambdaProxyProps",
     "TailscaleLambdaProxyPropsLambdaOption",
     "TailscaleLambdaProxyPropsOptions",
+    "TailscaleLambdaProxyPropsWarmerOption",
 ]
 
 publication.publish()
@@ -563,6 +655,15 @@ def _typecheckingstub__f012a3e49f709451167b5aea4e5d5e6bec3630984d9d528d842997a01
     *,
     extension: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.LayerVersionOptions, typing.Dict[builtins.str, typing.Any]]] = None,
     lambda_: typing.Optional[typing.Union[TailscaleLambdaProxyPropsLambdaOption, typing.Dict[builtins.str, typing.Any]]] = None,
+    warmer: typing.Optional[typing.Union[TailscaleLambdaProxyPropsWarmerOption, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ec060fb3c39fc12126fba615bdb9dfd4088bd14077c92dcc412180dec0a54ac3(
+    *,
+    concurrent_invocations: typing.Optional[jsii.Number] = None,
+    function_name: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
     pass
